#include "algorithm.hpp"
#include <ctime>
#include <iostream>
#include <chrono>

int main(int argc, char* argv[]) {
    if (argc != 2) {
        std::cerr << "Usage: search-algorithms graphFile.txt" << std::endl;
        return 1;
    }
    std::vector<Vertex*> solution;
    Graph newGraph = ReadInGraph(argv[1]);
    std::cout << "BFS" << std::endl;
    std::cout << "---" << std::endl;
    auto t_start = std::chrono::high_resolution_clock::now();
    PrintSolution(BFS(newGraph, 0, 0));
    auto t_end = std::chrono::high_resolution_clock::now();
    for (int i = 1; i < newGraph.nodeCount; i++) {
        PrintSolution(BFS(newGraph, 0, i));
    }
    std::cout << "BFS Time: " << std::chrono::duration<double, std::milli>(t_end-t_start).count() << std::endl;
    std::cout << "DFS" << std::endl;
    std::cout << "---" << std::endl;
    t_start = std::chrono::high_resolution_clock::now();
    solution = DFS(newGraph, 0, 0);
    PrintSolution(solution);
    t_end = std::chrono::high_resolution_clock::now();
    for (int i = 1; i < newGraph.nodeCount; i++) {
        PrintSolution(CleanSolution(DFS(newGraph, 0, i)));
    }
    std::cout << "DFS Time: " << std::chrono::duration<double, std::milli>(t_end-t_start).count() << std::endl;
    std::cout << "UCBFS" << std::endl;
    std::cout << "---" << std::endl;
    t_start = std::chrono::high_resolution_clock::now();
    UCBFS(newGraph, 1);
    t_end = std::chrono::high_resolution_clock::now();
    std::cout << "UCBFS Time: " << std::chrono::duration<double, std::milli>(t_end-t_start).count() << std::endl;
    return 0;
}
